@@ -4,7 +4,7 @@ import csv
 
 from tensorflow.python.keras.models import load_model
 
-from graphmanagerlib.Data_for_gcn import get_data
+from graphmanagerlib.Data_for_gcn import get_data, load_train_test_split
 from graphmanagerlib.Node import Node
 
 import stellargraph as sg
@@ -21,9 +21,12 @@ from tensorflow.python.keras.callbacks import EarlyStopping
 
 class GraphManager :
     def __init__(self, documents,save_dataset_fd):
-        get_data(documents=documents,save_dataset_fd=save_dataset_fd)
+        self.save_dataset_path = get_data(documents=documents,save_dataset_fd=save_dataset_fd)
 
     def TrainModel(self):
+        traindata, testdata = load_train_test_split(self.save_dataset_path)
+
+
         nodes = self.nodes
         nodes.reset_index(inplace=True)
         node_subjects = nodes['tag']
